# Sierra Wireless Development

Main Development for AgentBox is found under workspace/CL_Agents.

The Sierra Wireless module is responsible for the communication to the Quorum by forwarding information from [Engicam](Engicam.md) via UART to the MQTT broker and to signal switching information received from the Quorum via MQTT to the [Engicam](Engicam.md) over IO pins.

It is reachable over *SSH* via the IP address *192.168.2.2*.
The baudrate for the serial connection is *115200* Baud.

## Build
The build profiles (e.g. WP76xx, WP77xx, ...) are defined in *leaf-workspace.json*. To run a build, open Bash and switch to the workspace directory where the corresponding *.sdef-file* is defined. Install *leaf* in your Bash environment. On Debian systems run
```bash
wget https://downloads.sierrawireless.com/tools/leaf/leaf_latest.deb -O /tmp/leaf_latest.deb && sudo apt install /tmp/leaf_latest.deb
```

Select the corresponding leaf profile via
```bash
leaf select <profile-name>
```

Start the build process via the following command. *target* needs to be replaced by the chip target, e.g. *WP76xx*, sdef-file must be replaced by the corresponding *.sdef-file* name, e.g., *CL_Agent.sdef*.
```bash
leaf shell
mksys -t target sdef-file.sdef
```

## Connect
Connection to Sierra Wireless can be done via *SSH*. To do so connect to [Engicam](Engicam.md) via ```ssh root@192.168.175.10``` and then via ```ssh root@192.168.2.2``` to Sierra Wireless.

## Manual Application Update
Open a Bash terminal, move to the directory where the update-file is located and run the following script to update Sierra Wireless manually. **file-name** must be replaced by the actual .update-file name.

```bash
scp file-name.update root@192.168.175.10:/tmp/update_file.update && \
ssh root@192.168.175.10 "scp /tmp/update_file.update root@192.168.2.2:/tmp/update_file.update && ssh -oStrictHostKeyChecking=no root@192.168.2.2 '/legato/systems/current/bin/update /tmp/update_file.update && /sbin/reboot'"
```

## Firmware Update
To make sure the software is running reliably, the newest firmware should be flashed to the device. The firmware can either be retrieved from the current project setup where the *Linux distribution* and the *Legato framework* are usually located at *leaf-data -> current -> xxxx-linux-image*  and *leaf-data -> current -> xxxx-legato-image* or from the https://source.sierrawireless.com/resources/airprime/software/xxxx/xxxx-firmware-latest-release-components/ (*make sure to replace xxxx by the corresponding target. E.g., wp76xx*).

*If the update does not work on the Agent board itself, try to execute it via a mangOH board.*

### Windows
Updates on a Windows machine should be executed via the *[Module Firmware Download Tool (FDT)](https://source.sierrawireless.com/resources/airprime/software/fdt/)*. This tool needs to be called from the command line which runs with *Administrator* permissions. For further information have a look at the [documentation](Documents/FDT.pdf). E.g.,

```
fdt2.exe -f linux-SWI9X06Y_02.36.07.00.cwe
fdt2.exe -f legato-19.11.5.cwe
```

### Linux
Updates on Linux require the tools [swicwe](https://source.sierrawireless.com/resources/airprime/software/swicwe/) and [swiflash](https://source.sierrawireless.com/resources/airprime/software/swiflash/). *swicwe* is used to pack the Linux image and the Legato framework into one package. This package is then flashed via *swiflash*. E.g.,

```
swicwe -c "leaf-data/current/wp76-legato-image/legato.cwe" "leaf-data/current/wp76-linux-image/linux.cwe" -o "package.spk"
swiflash -m "wp76xx" -i "package.spk"
```

## Troubleshooting
If the software doesn't start at all or it crashes for a seemingly undefined reason make sure the following conditions are fulfilled.
1. SierraWireless runs the latest software (see [[#Firmware Update]]).
2. SierraWireless has all the required files in the */home/root* directory
	- config.xml
	- iot_state.txt
	- schema.rng
	- certs
		- cl-cacerts.pem
		- cl-cert.pem
		- cl-key.pem

Use *copy-required-files.sh* to copy the required files automatically.

## Helpful references
[Linux Upgrade](http://docs.legato.io/21_05/migrationGuide.html)
[Leaf installation Reference](https://docs.legato.io/20_08/toolsLeaf.html#toolsLeaf_install)
[AT Command Reference](https://scg-uae.com/wp-content/uploads/2019/02/4118047_WPx5xx-76xx-77xx-AT-Command-Reference_r6.pdf)
